"use client";

import React, { useState, useEffect } from "react";
import Link from "next/link";
import Modal from "react-modal";
import "@/stylesheets/navbar.scss";

const Navbar = () => {
  const [modal, setModal] = useState(false);
  const [modalOpacity, setModalOpacity] = useState(0);
  const [navBackground, setNavBackground] = useState({
    backgroundColor: "transparent",
  });
  useEffect(() => {
    document.addEventListener("scroll", (event) => {
      if (window.scrollY < 10) {
        setNavBackground({ backgroundColor: "transparent" });
      } else {
        setNavBackground({ backgroundColor: "#232323" });
      }
    });
  }, []);

  const modalStyle = {
    content: {
      opacity: modalOpacity,
      transition: "opacity 300ms ease-in-out",
      top: "50%",
      left: "50%",
      right: "auto",
      bottom: "auto",
      marginRight: "-50%",
      width: "100vw",
      height: "100vh",
      transform: "translate(-50%, -50%)",
      overflow: "hidden",
      display: "flex",
      flexDirection: "column",
      justifyContent: "flex-start",
      alignItems: "center",
      backgroundColor: "#232323",
      minWidth: "30%",
      minHeight: "30%",
      animation: "slideUp 500ms ease-in-out",
      border: "none",
    },
    overlay: {
      opacity: modalOpacity,
      transition: "opacity 300ms ease-in-out",
      backgroundColor: "rgba(255, 255, 255, 0.15)",
      backdropFilter: "blur(5px)",
      zIndex: "1000",
    },
  };

  const openModal = () => {
    setModal(true);
    setTimeout(() => setModalOpacity(1), 10);
  };

  const closeModal = () => {
    setModalOpacity(0);
    setTimeout(() => setModal(false), 300);
  };

  return (
    <div className="navbar" style={navBackground}>
      <Link className="navbar-logo" href="/">
        ITR
      </Link>
      <div className="navbar-links">
        <Link className="navbar-link" href="/">
          🏠 Home
        </Link>
        <Link className="navbar-link" href="/about">
          ❓ About
        </Link>
        <Link className="navbar-link" href="/projects">
          🤖 Projects
        </Link>
        <Link className="navbar-link" href="/gallery">
          📸 Gallery
        </Link>
      </div>
      <div
        className="navbar-hamburger"
        onClick={() => {
          openModal();
        }}
      >
        ≡
      </div>
      <Modal
        isOpen={modal}
        onRequestClose={() => closeModal()}
        contentLabel="Menu"
        style={modalStyle}
      >
        <div className="hamburger">
          <Link className="navbar-logo" href="/">
            ITR
          </Link>
          <div
            className="navbar-x"
            onClick={() => {
              closeModal();
            }}
          >
            ✕
          </div>
        </div>
        <div className="hamburger-links">
          <Link className="hamburger-link" href="/">
            🏠 Home
          </Link>
          <Link className="hamburger-link" href="/about">
            ❓ About
          </Link>
          <Link className="hamburger-link" href="/projects">
            🤖 Projects
          </Link>
          <Link className="hamburger-link" href="/gallery">
            📸 Gallery
          </Link>
        </div>
      </Modal>
    </div>
  );
};

export default Navbar;
